==> synergy_1.0.14.orig.tar.gz: synergy-1.0.14/cmd/launcher/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by launcher.rc
//
#define IDS_ERROR                       1
#define IDS_INVALID_SCREEN_NAME         2
#define IDS_DUPLICATE_SCREEN_NAME       3
#define IDS_SCREEN_NAME_IS_ALIAS        4
#define IDS_VERIFY                      5
#define IDS_UNSAVED_DATA_REALLY_QUIT    6
#define IDS_UNKNOWN_SCREEN_NAME         7
#define IDS_INVALID_PORT                8
#define IDS_SAVE_FAILED                 9
#define IDS_STARTUP_FAILED              10
#define IDS_STARTED_TITLE               11
#define IDS_STARTED                     12
#define IDS_INSTALL_FAILED              13
#define IDS_UNINSTALL_TITLE             14
#define IDS_UNINSTALLED                 15
#define IDS_UNINSTALL_FAILED            16
#define IDS_CLIENT                      17
#define IDS_SERVER                      18
#define IDS_AUTOSTART_PERMISSION_SYSTEM 19
#define IDS_AUTOSTART_PERMISSION_USER   20
#define IDS_AUTOSTART_PERMISSION_NONE   21
#define IDS_AUTOSTART_INSTALLED_SYSTEM  22
#define IDS_AUTOSTART_INSTALLED_USER    23
#define IDS_AUTOSTART_INSTALLED_NONE    24
#define IDS_INSTALL_LABEL               25
#define IDS_UNINSTALL_LABEL             26
#define IDS_INSTALL_GENERIC_ERROR       27
#define IDS_UNINSTALL_GENERIC_ERROR     28
#define IDS_INSTALL_TITLE               29
#define IDS_INSTALLED_SYSTEM            30
#define IDS_INSTALLED_USER              31
#define IDS_UNINSTALLED_SYSTEM          32
#define IDS_UNINSTALLED_USER            33
#define IDS_INVALID_SERVER_NAME         34
#define IDS_TITLE                       35
#define IDS_SERVER_IS_CLIENT            36
#define IDS_ADD_SCREEN                  37
#define IDS_EDIT_SCREEN                 38
#define IDS_INVALID_TIME                39
#define IDD_MAIN                        101
#define IDD_ADD                         102
#define IDD_WAIT                        103
#define IDI_SYNERGY                     104
#define IDD_AUTOSTART                   105
#define IDD_ADVANCED_OPTIONS            106
#define IDD_GLOBAL_OPTIONS              107
#define IDC_MAIN_CLIENT_RADIO           1000
#define IDC_MAIN_SERVER_RADIO           1001
#define IDC_MAIN_CLIENT_SERVER_NAME_EDIT 1002
#define IDC_MAIN_ADVANCED_NAME_EDIT     1006
#define IDC_MAIN_ADVANCED_PORT_EDIT     1008
#define IDC_MAIN_TEST                   1009
#define IDC_MAIN_SAVE                   1010
#define IDC_MAIN_CLIENT_SERVER_NAME_LABEL 1011
#define IDC_MAIN_SERVER_SCREENS_LIST    1012
#define IDC_MAIN_SERVER_SCREENS_LABEL   1013
#define IDC_MAIN_SERVER_LAYOUT_LABEL    1014
#define IDC_MAIN_SERVER_ADD_BUTTON      1018
#define IDC_MAIN_SERVER_EDIT_BUTTON     1019
#define IDC_ADD_SCREEN_NAME_EDIT        1020
#define IDC_MAIN_SERVER_REMOVE_BUTTON   1020
#define IDC_ADD_ALIASES_EDIT            1021
#define IDC_MAIN_SERVER_OPTIONS_BUTTON  1021
#define IDC_MAIN_SERVER_LEFT_COMBO      1022
#define IDC_MAIN_SERVER_RIGHT_COMBO     1023
#define IDC_MAIN_SERVER_TOP_COMBO       1024
#define IDC_MAIN_SERVER_BOTTOM_COMBO    1025
#define IDC_MAIN_SERVER_LEFT_LABEL      1026
#define IDC_MAIN_SERVER_RIGHT_LABEL     1027
#define IDC_MAIN_SERVER_TOP_LABEL       1028
#define IDC_MAIN_SERVER_BOTTOM_LABEL    1029
#define IDC_MAIN_UNINSTALL              1030
#define IDC_AUTOSTART_INSTALLED_MSG     1031
#define IDC_AUTOSTART_PERMISSION_MSG    1032
#define IDC_AUTOSTART_INSTALL_USER      1033
#define IDC_AUTOSTART_INSTALL_SYSTEM    1034
#define IDC_MAIN_AUTOSTART              1035
#define IDC_MAIN_OPTIONS                1036
#define IDC_ADD_HD_CAPS_CHECK           1037
#define IDC_MAIN_ADVANCED               1037
#define IDC_ADD_HD_NUM_CHECK            1038
#define IDC_ADVANCED_NAME_EDIT          1038
#define IDC_ADVANCED_PORT_EDIT          1039
#define IDC_MAIN_DEBUG                  1040
#define IDC_GLOBAL_DELAY_CHECK          1041
#define IDC_GLOBAL_DELAY_TIME           1042
#define IDC_GLOBAL_TWO_TAP_CHECK        1043
#define IDC_ADD_MOD_SHIFT               1043
#define IDC_GLOBAL_TWO_TAP_TIME         1044
#define IDC_ADD_MOD_CTRL                1044
#define IDC_ADD_MOD_ALT                 1045
#define IDC_GLOBAL_HEARTBEAT_CHECK      1045
#define IDC_ADD_MOD_META                1046
#define IDC_GLOBAL_HEARTBEAT_TIME       1046
#define IDC_ADD_MOD_SUPER               1047
#define IDC_GLOBAL_SCREENSAVER_SYNC     1047
#define IDC_ADVANCED_DEFAULTS           1049

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        110
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1052
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> synergy_1.2.2.orig.tar.gz: synergy-1.2.2/cmd/launcher/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by launcher.rc
//
#define IDS_ERROR                       1
#define IDS_INVALID_SCREEN_NAME         2
#define IDS_DUPLICATE_SCREEN_NAME       3
#define IDS_SCREEN_NAME_IS_ALIAS        4
#define IDS_VERIFY                      5
#define IDS_UNSAVED_DATA_REALLY_QUIT    6
#define IDS_UNKNOWN_SCREEN_NAME         7
#define IDS_INVALID_PORT                8
#define IDS_SAVE_FAILED                 9
#define IDS_STARTUP_FAILED              10
#define IDS_STARTED_TITLE               11
#define IDS_STARTED                     12
#define IDS_INSTALL_FAILED              13
#define IDS_UNINSTALL_TITLE             14
#define IDS_UNINSTALLED                 15
#define IDS_UNINSTALL_FAILED            16
#define IDS_CLIENT                      17
#define IDS_SERVER                      18
#define IDS_AUTOSTART_PERMISSION_SYSTEM 19
#define IDS_AUTOSTART_PERMISSION_USER   20
#define IDS_AUTOSTART_PERMISSION_NONE   21
#define IDS_AUTOSTART_INSTALLED_SYSTEM  22
#define IDS_AUTOSTART_INSTALLED_USER    23
#define IDS_AUTOSTART_INSTALLED_NONE    24
#define IDS_INSTALL_LABEL               25
#define IDS_UNINSTALL_LABEL             26
#define IDS_INSTALL_GENERIC_ERROR       27
#define IDS_UNINSTALL_GENERIC_ERROR     28
#define IDS_INSTALL_TITLE               29
#define IDS_INSTALLED_SYSTEM            30
#define IDS_INSTALLED_USER              31
#define IDS_UNINSTALLED_SYSTEM          32
#define IDS_UNINSTALLED_USER            33
#define IDS_INVALID_SERVER_NAME         34
#define IDS_TITLE                       35
#define IDS_SERVER_IS_CLIENT            36
#define IDS_ADD_SCREEN                  37
#define IDS_EDIT_SCREEN                 38
#define IDS_INVALID_TIME                39
#define IDS_ERROR_CODE                  39
#define IDS_AUTOSTART_PERMISSION_ALL    40
#define IDS_INVALID_INTERFACE_NAME      41
#define IDD_MAIN                        101
#define IDD_ADD                         102
#define IDD_WAIT                        103
#define IDI_SYNERGY                     104
#define IDD_AUTOSTART                   105
#define IDD_ADVANCED_OPTIONS            106
#define IDD_GLOBAL_OPTIONS              107
#define IDC_MAIN_CLIENT_RADIO           1000
#define IDC_MAIN_SERVER_RADIO           1001
#define IDC_MAIN_CLIENT_SERVER_NAME_EDIT 1002
#define IDC_MAIN_ADVANCED_NAME_EDIT     1006
#define IDC_MAIN_ADVANCED_PORT_EDIT     1008
#define IDC_MAIN_TEST                   1009
#define IDC_MAIN_SAVE                   1010
#define IDC_MAIN_CLIENT_SERVER_NAME_LABEL 1011
#define IDC_MAIN_SERVER_SCREENS_LIST    1012
#define IDC_MAIN_SERVER_SCREENS_LABEL   1013
#define IDC_MAIN_SERVER_LAYOUT_LABEL    1014
#define IDC_MAIN_SERVER_ADD_BUTTON      1018
#define IDC_MAIN_SERVER_EDIT_BUTTON     1019
#define IDC_ADD_SCREEN_NAME_EDIT        1020
#define IDC_MAIN_SERVER_REMOVE_BUTTON   1020
#define IDC_ADD_ALIASES_EDIT            1021
#define IDC_MAIN_SERVER_OPTIONS_BUTTON  1021
#define IDC_MAIN_SERVER_LEFT_COMBO      1022
#define IDC_MAIN_SERVER_RIGHT_COMBO     1023
#define IDC_MAIN_SERVER_TOP_COMBO       1024
#define IDC_MAIN_SERVER_BOTTOM_COMBO    1025
#define IDC_MAIN_SERVER_LEFT_LABEL      1026
#define IDC_MAIN_SERVER_RIGHT_LABEL     1027
#define IDC_MAIN_SERVER_TOP_LABEL       1028
#define IDC_MAIN_SERVER_BOTTOM_LABEL    1029
#define IDC_MAIN_UNINSTALL              1030
#define IDC_AUTOSTART_INSTALLED_MSG     1031
#define IDC_AUTOSTART_PERMISSION_MSG    1032
#define IDC_AUTOSTART_INSTALL_USER      1033
#define IDC_AUTOSTART_INSTALL_SYSTEM    1034
#define IDC_MAIN_AUTOSTART              1035
#define IDC_MAIN_OPTIONS                1036
#define IDC_ADD_HD_CAPS_CHECK           1037
#define IDC_MAIN_ADVANCED               1037
#define IDC_ADD_HD_NUM_CHECK            1038
#define IDC_ADVANCED_NAME_EDIT          1038
#define IDC_ADVANCED_PORT_EDIT          1039
#define IDC_ADD_HD_SCROLL_CHECK         1039
#define IDC_MAIN_DEBUG                  1040
#define IDC_ADVANCED_INTERFACE_EDIT     1040
#define IDC_GLOBAL_DELAY_CHECK          1041
#define IDC_GLOBAL_DELAY_TIME           1042
#define IDC_GLOBAL_TWO_TAP_CHECK        1043
#define IDC_ADD_MOD_SHIFT               1043
#define IDC_GLOBAL_TWO_TAP_TIME         1044
#define IDC_ADD_MOD_CTRL                1044
#define IDC_ADD_MOD_ALT                 1045
#define IDC_GLOBAL_HEARTBEAT_CHECK      1045
#define IDC_ADD_MOD_META                1046
#define IDC_GLOBAL_HEARTBEAT_TIME       1046
#define IDC_ADD_MOD_SUPER               1047
#define IDC_GLOBAL_SCREENSAVER_SYNC     1047
#define IDC_GLOBAL_RELATIVE_MOVES       1048
#define IDC_ADVANCED_DEFAULTS           1049

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        110
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1052
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
